agentle.mcp.tools.input\_schema
===============================

.. automodule:: agentle.mcp.tools.input_schema

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      InputSchema
   